@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 # --------------* TO DO *-------------- #
 
@@ -166,14 +167,13 @@ def check_service(verbose):
     for i in range(len(service_check)):
         print(f"systemctl status {service_check[i]} | grep active")
         active = os.system(f"systemctl status {service_check[i]} | grep active")
-        if str(active).find("active"):
-            print("Service is active")
-            pass
-
-        elif str(active).find("inactive"):
+        if str(active).find("inactive"):
             print(f"Service is inactive \nLaunch of the restart of the services {service_check[i]}")
             service_down(service_check[i], verbose)
 
+        elif str(running).find("active"):
+            print("Service is active")
+
 
 def service_down(service, verbose):
     global active
@@ -185,13 +185,12 @@ def service_down(service, verbose):
     number_restart = 3
     for i in range(number_restart):
         print(f"Relaunching n°{i}/{number_restart}")
-        active = os.system(f"systemctl status {service} | grep active")
+        active = os.system(f"systemctl status {service}")
         if str(active).find("inactive"):
             os.system(f"systemctl restart {service}")
             continue
-        elif str(active).find("active"):
+        elif str(active).find("running"):
             print(f"Successful restarting service {service}")
-            break
         else:
             print("Error, we do not know the status of this service")
             continue
@@ -204,6 +203,7 @@ def service_down(service, verbose):
 
 
 def send_mail(subject, verbose):
+    global sender_email, email_password, smtp_server, email_smtp_port, receiver_email
     if verbose:
         enablePrint()
 
@@ -218,16 +218,18 @@ def send_mail(subject, verbose):
         From Auto_Check_service Python Bot"""
 
     context = ssl.create_default_context()
-    try:
-        with smtplib.SMTP_SSL(smtp_server, email_smtp_port, context=context) as server:
-            server.login(sender_email, email_password)
+    print("Sending mail...")
+    #try:
+    with smtplib.SMTP_SSL(smtp_server, email_smtp_port, context=context) as server:
+        server.login(sender_email, email_password)
 
-            server.sendmail(sender_email, receiver_email, message)
+        server.sendmail(sender_email, receiver_email, message).encode('utf-8')
 
-            print("Successful sending mail")
+        print("Successful sending mail")
 
-    except:
-        print("Sending error please check the sender's email and password or the receiver's")
+    #except:
+        #print(f"Sending error please check the sender's email ({sender_email}) and password or the receiver's "
+              #f"({receiver_email})")
 
 
 def daemon():
